@@ -1,6 +1,5 @@
 `center.step` <-
 function(datas,A,maxiter,eps.center)                                            
     {
-     solve(A)%*%spatial.median(datas%*%t(A),init=NULL,maxiter=maxiter,eps=eps.center,print.it=FALSE) 
+     spatial.median(datas%*%t(A),init=NULL,maxiter=maxiter,eps=eps.center,print.it=FALSE) %*% solve(A)
     }
-
